#!/usr/bin/env python
# -*- coding: UTF-8 -*-
"""
eBook finder using google search engine (via pygoogle)

This file just contains GUI code from wxGlade (and add my hack code).
Actual process functions are being separated source code files.

@author:    Charlie Kim <nabugoon@gmail.com>
@license:   BPL
@version:   0.1
"""

import os
import string
import webbrowser
import wx
import agent

class EBFWindow(wx.Frame):
    def __init__(self, *args, **kwds):
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        self.tcInput = wx.TextCtrl(self, -1, "", style=wx.TE_PROCESS_ENTER)
        self.btnSearch = wx.Button(self, -1, "Search")
        self.lbURI = wx.ListBox(self, -1, choices=[])
        self.listURI = []

        self.__set_properties()
        self.__do_layout()

        self.agent = None
        self._search = 0

        self.Bind(wx.EVT_TEXT_ENTER, self.OnTextEnter, self.tcInput)
        self.Bind(wx.EVT_BUTTON, self.OnButton, self.btnSearch)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.OnDBClick, self.lbURI)
        agent.EVT_APPEND(self, self.OnAppend)
        agent.EVT_RESULT(self, self.OnResult)

        self.tcInput.SetFocus()

    def __set_properties(self):
        self.SetTitle("eBookFinder")
        self.SetSize((400, 300))

    def __do_layout(self):
        bsMain = wx.BoxSizer(wx.VERTICAL)
        bsInput = wx.BoxSizer(wx.HORIZONTAL)
        bsInput.Add(self.tcInput, 1, wx.ALIGN_CENTER_VERTICAL|wx.FIXED_MINSIZE, 0)
        bsInput.Add(self.btnSearch, 0, wx.LEFT|wx.ALIGN_CENTER_VERTICAL|wx.FIXED_MINSIZE, 5)
        bsMain.Add(bsInput, 0, wx.ALL|wx.EXPAND, 5)
        bsMain.Add(self.lbURI, 1, wx.ALL|wx.EXPAND, 5)
        #self.SetAutoLayout()
        self.SetSizer(bsMain)
        self.Layout()
        self.Centre()

    def OnTextEnter(self, e):
        self.OnButton(e)        

    def OnButton(self, e):
        if self._search and self.agent:
            self.agent.abort()
            self._search = 0
            self.btnSearch.SetLabel("Search")
            return
        
        self._search = 1
        self.btnSearch.SetLabel("Stop")
        self.listURI = []
        self.lbURI.Clear()
        query = self.tcInput.GetValue()
        self.agent = agent.SearchBot(query, self)

    def OnDBClick(self, e):
    	selectedURI = self.listURI[self.lbURI.GetSelection()]
        #wx.MessageBox(selectedURI[0])
        webbrowser.open(selectedURI[0])

    def OnAppend(self, e):
        self.listURI.append(e.data)
        self.lbURI.Append(string.replace(e.data[1], "%20", " "))

    def OnResult(self, e):
        self.agent = None
        self._search = 0
        self.btnSearch.SetLabel("Search")

class EBookFinder(wx.App):
    def OnInit(self):
        wx.InitAllImageHandlers()
        frame = EBFWindow(None, -1, "")
        self.SetTopWindow(frame)
        frame.Show(1)
        return 1

if __name__ == "__main__":
    app = EBookFinder(0)
    app.MainLoop()